@@ -1,3 +1,5 @@
+from reinvent_models.lib_invent.enums.generative_model_regime import GenerativeModelRegimeEnum
+
 from reinvent_models.model_factory.enums.model_mode_enum import ModelModeEnum
 from reinvent_models.model_factory.generative_model_base import GenerativeModelBase
 from reinvent_models.reinvent_core.models.model import Model
@@ -6,6 +8,8 @@ from reinvent_models.reinvent_core.models.model import Model
 class ReinventCoreAdapter(GenerativeModelBase):
 
     def __init__(self, path_to_file: str, mode: str):
+        model_regime = GenerativeModelRegimeEnum()
+        mode = mode == model_regime.INFERENCE
         self.generative_model = Model.load_from_file(path_to_file, mode)
         self.vocabulary =  self.generative_model.vocabulary
         self.tokenizer =  self.generative_model.tokenizer
@@ -23,7 +27,8 @@ class ReinventCoreAdapter(GenerativeModelBase):
         return self.generative_model.sample_sequences_and_smiles(batch_size)
 
     def set_mode(self, mode: str):
-        self.generative_model.set_mode(mode)
+        raise NotImplemented("set_mode method is not implemented")
+        # self.generative_model.set_mode(mode)
 
     def get_network_parameters(self):
         return self.generative_model.get_network_parameters()
